@@ -13,11 +13,11 @@ except ImportError as e:
         exc_info=e,
     )
 
-VERSION = (0, 2, 5)
+VERSION = (0, 2, 6)
 
 __version__ = ".".join([str(i) for i in VERSION])
 __author__ = "nielstron"
 __author_email__ = "n.muendler@web.de"
-__copyright__ = "Copyright (C) 2019 nielstron"
+__copyright__ = "Copyright (C) 2023 nielstron"
 __license__ = "MIT"
-__url__ = "https://github.com/imperatorlang/plyto"
+__url__ = "https://github.com/imperatorlang/pluthon"
